const { Pool } = require('pg');
const userutil = require('util');
let pool = null;

var UPOSTGRES = UPOSTGRES || {};
UPOSTGRES.databaseConnected = false;

UPOSTGRES.initDatabase = async function(postgresConfig) {
    if (pool == null) {
        pool = new Pool({
            user: postgresConfig['user'],
            host: postgresConfig['host'],
            database: postgresConfig['database'],
            password: postgresConfig['password'],
            port: postgresConfig['port'],
            max: 10 // connectionLimit equivalent
        });
    }
    console.log("done init");
};

UPOSTGRES.testConnection = async function(postgresConfig) {
    try {
        const testPool = new Pool({
            user: postgresConfig['user'],
            host: postgresConfig['host'],
            database: postgresConfig['database'],
            password: postgresConfig['password'],
            port: postgresConfig['port'],
            max: 1
        });

        await testPool.query('SELECT 1');
        await testPool.end();

        return true;
    } catch (error) {
        console.error('Error testing database connection:', error);
        return false;
    }
};

UPOSTGRES.getSchemas = async function() {
    try {
        const result = await pool.query('SELECT schema_name FROM information_schema.schemata');
        return result.rows.map(row => row.schema_name);
    } catch (error) {
        console.error('Error retrieving schemas:', error);
        return [];
    }
};

UPOSTGRES.getTables = async function(schema) {
    try {
        const result = await pool.query(`
            SELECT table_name 
            FROM information_schema.tables 
            WHERE table_schema = $1
        `, [schema]);
        return result.rows.map(row => row.table_name);
    } catch (error) {
        console.error(`Error retrieving tables for schema ${schema}:`, error);
        return [];
    }
};

UPOSTGRES.getTableStructure = async function(schema) {
    try {
        const tables = await UPOSTGRES.getTables(schema);
        let structure = '';
        for (const table of tables) {
            structure += `${table}\n`;
            const columns = await pool.query(`
                SELECT column_name, data_type, 
                       CASE WHEN is_nullable = 'NO' THEN 'NOT NULL' ELSE 'NULL' END AS nullable,
                       CASE WHEN column_name = ANY(pk.column_names) THEN 'PRIMARY KEY' ELSE '' END AS key
                FROM information_schema.columns c
                LEFT JOIN (
                    SELECT kcu.table_schema, kcu.table_name, array_agg(kcu.column_name) AS column_names
                    FROM information_schema.table_constraints tc
                    JOIN information_schema.key_column_usage kcu ON tc.constraint_name = kcu.constraint_name
                    WHERE tc.constraint_type = 'PRIMARY KEY'
                    GROUP BY kcu.table_schema, kcu.table_name
                ) pk ON c.table_schema = pk.table_schema AND c.table_name = pk.table_name
                WHERE c.table_schema = $1 AND c.table_name = $2
                ORDER BY c.ordinal_position
            `, [schema, table]);
            for (const column of columns.rows) {
                structure += `- ${column.column_name} (${column.data_type}, ${column.nullable}${column.key ? ', ' + column.key : ''})\n`;
            }
            structure += '\n';
        }
        return structure;
    } catch (error) {
        console.error(`Error retrieving table structure for schema ${schema}:`, error);
        return '';
    }
};

module.exports = UPOSTGRES;