
const startButton = document.getElementById('startButton');
const transcriptDiv = document.getElementById('transcript');
let isRecording = false;
let audioContext;
let processor;
let input;
let globalStream;

function convertFloat32ToInt16(buffer) {
  const l = buffer.length;
  const buf = new Int16Array(l);
  for (let i = 0; i < l; i++) {
    let s = Math.max(-1, Math.min(1, buffer[i]));
    buf[i] = s < 0 ? s * 0x8000 : s * 0x7FFF;
    buf[i] = Math.round(s);
  }
  return buf;
}

function stopRecording() {
  debugLog('Stop recording');
  isRecording = false;
  startButton.textContent = 'Start Recording';
  if (processor && input) {
    processor.disconnect();
    input.disconnect();
  }
  if (globalStream) {
    globalStream.getTracks().forEach(track => track.stop());
  }
  if (audioContext) {
    audioContext.close();
  }
}

startButton.addEventListener('click', async () => {
  if (!isRecording) {
    debugLog('Start recording');
    isRecording = true;
    startButton.textContent = 'Stop Recording';
    audioContext = new AudioContext({ sampleRate: 24000 });
    globalStream = await navigator.mediaDevices.getUserMedia({ audio: true });
    input = audioContext.createMediaStreamSource(globalStream);

    processor = audioContext.createScriptProcessor(2048, 1, 1);
    processor.onaudioprocess = (e) => {
      const inputData = e.inputBuffer.getChannelData(0);
      const int16Data = convertFloat32ToInt16(inputData);
      // Send audio data to the main process
      window.electronAPI.sendAudioData(int16Data);
    };

    input.connect(processor);
    processor.connect(audioContext.destination);

    // Optionally, create a response after starting
    setTimeout(() => {
      //window.electronAPI.createResponse();
    }, 1000);
  } else {
    debugLog('Stop recording');
    isRecording = false;
    startButton.textContent = 'Start Recording';
    window.electronAPI.sendCancelEvent();
    stopRecording();
  }
});

function playAudio(int16Array) {
  const audioCtx = new (window.AudioContext || window.webkitAudioContext)({ sampleRate: 24000 });
  const buffer = audioCtx.createBuffer(1, int16Array.length, 24000);
  const float32Array = new Float32Array(int16Array.length);

  for (let i = 0; i < int16Array.length; i++) {
    float32Array[i] = int16Array[i] / 0x8000;
  }

  buffer.copyToChannel(float32Array, 0);
  const source = audioCtx.createBufferSource();
  source.buffer = buffer;
  source.connect(audioCtx.destination);
  source.start();
}

window.electronAPI.onConversationUpdated(({ item, delta }) => {
  debugLog('Conversation updated');
  if (delta) {
    if (delta.transcript) {
      transcriptDiv.innerText += delta.transcript;
    }
    if (delta.audio) {
      playAudio(delta.audio);
    }
  }

  // Optionally, create a new response after playing audio
  if (delta && delta.audio && isRecording) {
    setTimeout(() => {
      //window.electronAPI.createResponse();
    }, 500);
  }
});

function debugLog(message) {
  console.log(`Debug: ${message}`);
  window.electronAPI.sendDebugData(message);
}