// Create an MD5 hash of a file
function getMD5HashOfFile(filePath) {
    
    const fileBuffer = readFileWithCache(filePath);
    return crypto.createHash('md5').update(fileBuffer).digest('hex');
}

function getProjectFileInfo(filePath) {
    try {
        const fileBuffer = readFileWithCache(filePath);
        
        // Get MD5 hash of the file
        const md5Hash = crypto.createHash('md5').update(fileBuffer).digest('hex');
        
        // Count the number of lines in the file
        const lineCount = fileBuffer.toString().split('\n').length;
        const charCount = fileBuffer.toString().length;
        // Return the MD5 hash and line count in an object
        return {
            md5_hash: md5Hash,
            line_count: lineCount,
            character_count: charCount
        };
    } catch (error) {
        console.error("File reading error occurred:", error);
        return null;
    }
}

async function processItem(projectName, projectPath, fullPath) {
    const stats = fs.statSync(fullPath);
    //console.log("processing item:");
    //console.log(fullPath);
    const filePath = path.relative(projectPath, fullPath);

    // Skip over node_modules directories and their contents
    if (filePath.includes('node_modules') || filePath.includes('stubble') || filePath.includes('vendor') || filePath.startsWith('.git') || filePath.startsWith('stubdiff')) {
        console.log("Shouldnt happen processItem - item blocked because in known library folder: " + fullPath);
        return;
    }
    
    //for my projects, need to add...   .tpl
    let stubFileTypes = STUBS.SUPPORTED_FILE_TYPES;
    
    if (stats.isDirectory()) {
        await createStubsForDirectory(projectName, projectPath, fullPath);
    } else if (stubFileTypes.includes(path.extname(fullPath))) {
        //console.log("item is stub file");
        createStubForProjectFile(projectName, projectPath, fullPath);
    }else{
        //console.log("item is OTHER file");        
        createStubForOtherFile(projectName, projectPath, fullPath);
    }
}

async function createStubsForDirectory(projectName, projectPath, directoryPath) {
    const items = fs.readdirSync(directoryPath);    

    for (const item of items) {
        let filePath = path.join(directoryPath, item);
        let filePath2 = path.normalize(filePath).replace(/\\/g, '/');
        let shortPath = path.normalize(filePath.replace(projectPath, '')).replace(/\\/g, '/');
        //const stubFilePath = path.join('./stubble/', projectName, shortPath);
        
        if(gitignore != null && gitignore.denies(shortPath)){            
            removeStubData(projectName, shortPath);
            continue;
        }  
        if(stubignore != null && stubignore.denies(shortPath)){
            removeStubData(projectName, shortPath);
            continue;
        }else{
            //console.log("createStubsForDirectory stubgenerator doing: " + shortPath);
        }       
        //console.log("processing " + filePath);
        await processItem(projectName, projectPath, filePath);
    }
};


function removeStubData(projectName, filePath) {
  if (STUBS.stubsData[projectName]) {
    //console.log("trying to delete " + filePath);

    // Split the file path on the slashes and remove empty strings
    const filePathPieces = filePath.split(/[\\/]/).filter(piece => piece !== '');

    // Find the index of the stub with matching file path pieces
    const index = STUBS.stubsData[projectName].findIndex(stub => {
      const stubPathPieces = stub.file_path.split(/[\\/]/).filter(piece => piece !== '');

      // Compare the length of the path pieces
      if (stubPathPieces.length !== filePathPieces.length) {
        return false;
      }

      // Compare each piece of the path
      for (let i = 0; i < stubPathPieces.length; i++) {
        if (stubPathPieces[i] !== filePathPieces[i]) {
          return false;
        }
      }

      return true;
    });

    if (index > -1) {
      //console.log("delete index " + index);
      STUBS.stubsData[projectName].splice(index, 1);
      dexieDB.deleteEmbedding(projectName, filePath);
    }
  }

}


async function createStubForProjectFile(projectName, projectPath, filePath) {
    const relativePath = path.relative(projectPath, filePath);    
    let filePath2 = path.normalize(relativePath).replace(/\\/g, '/');
    let isIncluded = true;
    if(gitignore != null && gitignore.denies(filePath2)){
        isIncluded = false;
    }  
    if(stubignore != null && stubignore.denies(filePath2)){
        isIncluded = false;
    }         
    //const fileInfo = getProjectFileInfo(filePath);
    if(!fs.existsSync(filePath)){
        console.log("bad file: " + filePath);
        return;
    }    
    let foundIndex = STUBS.stubsData[projectName]?.findIndex(stub => stub.full_path === filePath);

    if (foundIndex >= 0) {
        //We don't do anything, it will be updated if md5 hash same
        //STUBS.stubsData[projectName][foundIndex] = {
        //    ...STUBS.stubsData[projectName][foundIndex],
        //    line_count: fileInfo.line_count
        //};
        //except if the included status has changed
        STUBS.stubsData[projectName][foundIndex]['is_included'] = isIncluded;
        //if ignored doesnt need stub
        STUBS.stubsData[projectName][foundIndex]['needs_stub'] = isIncluded;
        if(!STUBS.stubsData[projectName][foundIndex]['stub_file']){
            //clear md5 if stub empty
            STUBS.stubsData[projectName][foundIndex]['md5'] = '';
        }
    } else { 
        let md5Hash = '';
        let lineCount = 0;
        let characterCount = 0;

        // Update the stub data
        if (!STUBS.stubsData[projectName]) {
            STUBS.stubsData[projectName] = [];
        }
        let needsStub = true;        
        
        //empty md5 hash is needed for new ones
        STUBS.stubsData[projectName].push({
            md5: '', 
            line_count: lineCount, 
            needs_stub: needsStub,
            is_included: isIncluded,
            full_path: filePath,
            file_path: relativePath,
            filename: path.basename(filePath),
            stub_file: ''
        });
    }
}

async function createStubForOtherFile(projectName, projectPath, filePath) {
    const relativePath = path.relative(projectPath, filePath);    
    const fileInfo = getProjectFileInfo(filePath);
    if(fileInfo == null){
        console.log("bad file: " + filePath);
        return;
    }    
    let filePath2 = path.normalize(relativePath).replace(/\\/g, '/');
    if(gitignore != null && gitignore.denies(filePath2)){
        console.log("createStubForProjectFile gitignore skipping file: " + projectName + " - " + filePath2);
        return;
    }  
    if(stubignore != null && stubignore.denies(filePath2)){
        console.log("createStubForProjectFile stubignore skipping file: " + projectName + " - " + filePath2);
        return;
    }     
    let foundIndex = STUBS.stubsData[projectName]?.findIndex(stub => stub.full_path === filePath);

    if (foundIndex >= 0) {
        // Update existing entry
        STUBS.stubsData[projectName][foundIndex] = {
            ...STUBS.stubsData[projectName][foundIndex],
            md5: fileInfo.md5_hash,
            line_count: fileInfo.line_count
        };
    }else{     
    
        let md5Hash = fileInfo['md5_hash'];
        let lineCount = fileInfo['line_count'];

        // Update the stub data
        if (!STUBS.stubsData[projectName]) {
            STUBS.stubsData[projectName] = [];
        }

        let otherCodeFileTypes = STUBS.INCLUDED_FILE_TYPES;
        let isIncluded = false;
        if(otherCodeFileTypes.includes(path.extname(filePath))){
            //html css tpl files are not going to have stubs, but they will have context functions to find relavant parts 
            //related to a task... 
            //
            isIncluded = true;
        }


        STUBS.stubsData[projectName].push({
            md5: md5Hash,
            line_count: lineCount,         
            needs_stub: false,        
            is_included: isIncluded,
            full_path: filePath,
            file_path: relativePath,
            filename: path.basename(filePath),
            stub_file: ''
        });
    }
}


async function createStubsForProject(aproject) {
    const existingFiles = new Set();
    let defaultStubIgnore = STUBS.isPackaged ? path.join(STUBS.appPath, '.defaultstubignore') : path.join(__dirname, '.defaultstubignore');
    const projectPath = aproject.folder;
    let projectName = aproject.project_slug;

    // load gitignore here?
    let gitignoreFile = path.join(projectPath, '.gitignore');
    let stubignoreFile = path.join(projectPath, '.stubignore');

    let myGitIgnore = null;
    let myStubIgnore = null;
    if (fs.existsSync(gitignoreFile)) {
        let contentOfGitIgnore = readFileWithCache(gitignoreFile);   
        myGitIgnore = gitignoreParser.compile(contentOfGitIgnore);
        gitignore = myGitIgnore;
    } else {
        gitignore = null;
    }
    if (fs.existsSync(stubignoreFile)) {
        let contentOfStubIgnore = readFileWithCache(stubignoreFile);   
        myStubIgnore = gitignoreParser.compile(contentOfStubIgnore);
        stubignore = myStubIgnore;
    } 
    else {
        let contentOfDefaultIgnore = readFileWithCache(defaultStubIgnore);           
        myStubIgnore = gitignoreParser.compile(contentOfDefaultIgnore);
        stubignore = myStubIgnore;
    }

    await createStubsForDirectory(projectName, projectPath, projectPath);

    // Mark all files in this project as existing
    if (STUBS.stubsData[projectName]) {
        for (const stub of STUBS.stubsData[projectName]) {
            existingFiles.add(path.join(projectPath, stub.file_path));
        }
    } 
    return STUBS.stubsData;
}

// Main function to generate stubs for all projects
/*
async function createAllStubsForProjects(projectArr) {

    let stubData = {};
    
   
    // Store existing files in a set for quick lookup
    const existingFiles = new Set();
    const defaultStubIgnore = STUBS.isPackaged ? path.join(STUBS.appPath, '.defaultstubignore') : path.join(__dirname, '.defaultstubignore');
    
    for(const aproject of STUBS.projectArr) {
        const projectPath = aproject.folder;
        let projectName = aproject.project_slug;
        
        // load gitignore here?
        let gitignoreFile = path.join(projectPath, '.gitignore');
        let stubignoreFile = path.join(projectPath, '.stubignore');
        
        let myGitIgnore = null;
        let myStubIgnore = null;
        if (fs.existsSync(gitignoreFile)) {
            myGitIgnore = gitignoreParser.compile(fs.readFileSync(gitignoreFile, 'utf8'));
            gitignore = myGitIgnore;
        } else {
            gitignore = null;
        }
        if (fs.existsSync(stubignoreFile)) {
            myStubIgnore = gitignoreParser.compile(fs.readFileSync(stubignoreFile, 'utf8'));
            stubignore = myStubIgnore;
        } 
        else {
            myStubIgnore = gitignoreParser.compile(fs.readFileSync(defaultStubIgnore, 'utf8'));
            stubignore = myStubIgnore;
        }
        
        stubData = await createStubsForDirectory(projectName, projectPath, projectPath, stubData);

        // Mark all files in this project as existing
        if (stubData[projectName]) {
            for (const stub of stubData[projectName]) {
                existingFiles.add(path.join(projectPath, stub.file_path));
            }
        }
    }

    // Remove stubs for files that no longer exist
    for(const aproject of STUBS.projectArr) {
        STUBS.stubsData[aproject.project_slug] = stubData[aproject.project_slug].filter(stub => existingFiles.has(path.join(aproject.folder, stub.file_path)));
    }
    
    console.log("stub object based on current file directory: ");
    console.log(STUBS.stubsData);
    
}
*/

//------------------------------------------------------------
//Calling process_treesit.js 
/*
async function processProjectFiles(projectName, projectQueue) {
    const child = spawn('node', ['./process_treesit.js', projectName]);

    child.stdout.on('data', (data) => {
        if(STUBS.LOG_STUBCREATION){
            console.log(`stdout: ${data}`);
        }
        let dataStr = data.toString();  // Convert buffer to string
        try{
            if(dataStr.indexOf('[progress=') >= 0){
                let startIndex = dataStr.indexOf('[progress=');
                let endIndex = dataStr.indexOf(']', startIndex);    
                let progressString = dataStr.substring(startIndex, endIndex);            
                let progressNums = progressString.split('=')[1];
                let totalArr = progressNums.split('|');
                let fileNum = parseInt(totalArr[0]);
                let totalNum = parseInt(totalArr[1]);
                //let thePercent = Math.floor((fileNum / totalNum) * 100);                
                updateProgressBar(projectName, fileNum, totalNum);
            }
        }catch(exxx){
            console.log("progress error?");
            console.log(exxx);
        }
        // You can parse data to update the project's progress bar
    });

    child.stderr.on('data', (data) => {
        console.error(`stderr: ${data}`);
    });

    child.on('close', async (code) => {
        console.log(`Processing for project ${projectName} exited with code ${code}`);
        // After one project's processing is done, trigger the next project's processing
        const nextProjectIndex = projectQueue.indexOf(projectName) + 1;
        if (nextProjectIndex < projectQueue.length) {
            const nextProject = projectQueue[nextProjectIndex];
            await processProjectFiles(nextProject, projectQueue, nextProjectIndex);
        }
        await updateMD5HashForProcessedFiles(projectName);
    });
}
*/
/*
function processProjectFiles(projectName, projectQueue, callback) {
  const child = spawn('node', ['./process_treesit.js', projectName]);

  child.stdout.on('data', (data) => {
        if(STUBS.LOG_STUBCREATION){
            console.log(`stdout: ${data}`);
        }
        let dataStr = data.toString();  // Convert buffer to string
        try{
            if(dataStr.indexOf('[progress=') >= 0){
                let startIndex = dataStr.indexOf('[progress=');
                let endIndex = dataStr.indexOf(']', startIndex);    
                let progressString = dataStr.substring(startIndex, endIndex);            
                let progressNums = progressString.split('=')[1];
                let totalArr = progressNums.split('|');
                let fileNum = parseInt(totalArr[0]);
                let totalNum = parseInt(totalArr[1]);
                //let thePercent = Math.floor((fileNum / totalNum) * 100);                
                updateProgressBar(projectName, fileNum, totalNum);
            }
        }catch(exxx){
            console.log("progress error?");
            console.log(exxx);
        }
        // You can parse data to update the project's progress bar
  });

  child.stderr.on('data', (data) => {
    console.error(`stderr: ${data}`);
  });

  child.on('close', async (code) => {
    console.log(`Processing for project ${projectName} exited with code ${code}`);
    await updateMD5HashForProcessedFiles(projectName);

    // After one project's processing is done, trigger the next project's processing
    const nextProjectIndex = projectQueue.indexOf(projectName) + 1;
    if (nextProjectIndex < projectQueue.length) {
      const nextProject = projectQueue[nextProjectIndex];
      processProjectFiles(nextProject, projectQueue, callback);
    } else {
      // All projects have been processed, invoke the callback
      callback();
    }
  });
}
*/

function processProjectFiles(projectName, projectQueue, callback) {
  let projectPath = "";
  let gitignore = null;
  let stubignore = null;

  // Find the project path
  for (let p = 0; p < STUBS.projectArr.length; p++) {
    if (STUBS.projectArr[p].project_slug == projectName) {
      projectPath = STUBS.projectArr[p].folder;
      break;
    }
  }

  if (projectPath == '') {
    console.error("Project path not found for project: " + projectName);
    callback();
    return;
  }

  // Load gitignore and stubignore
  let gitignoreFile = path.join(projectPath, ".gitignore");
  if (fs.existsSync(gitignoreFile)) {
    let contentOfGitIgnore = readFileWithCache(gitignoreFile);         
    gitignore = gitignoreParser.compile(contentOfGitIgnore);
  }
  let stubignoreFile = path.join(projectPath, ".stubignore");
  if (fs.existsSync(stubignoreFile)) {
    let contentOfStubIgnore = readFileWithCache(stubignoreFile);               
    stubignore = gitignoreParser.compile(contentOfStubIgnore);
  }

  processProjectFilesInternal(projectName, projectPath, gitignore, stubignore, async function () {
    // After one project's processing is done, trigger the next project's processing
    const nextProjectIndex = projectQueue.indexOf(projectName) + 1;
    if (nextProjectIndex < projectQueue.length) {
      const nextProject = projectQueue[nextProjectIndex];
      processProjectFiles(nextProject, projectQueue, callback);
    } else {
      // All projects have been processed, invoke the callback
      callback();
    }
  });
}


async function processProjectFilesInternal(projectName, projectPath, gitignore, stubignore, callback) {
  console.log("IN processProjectFilesInternal for " + projectName);
  let fileArr = STUBS.stubsData[projectName];
  let totalFiles = fileArr.length - 1;
  const defaultStubIgnore = STUBS.isPackaged ? path.join(STUBS.appPath, '.defaultstubignore') : path.join(__dirname, '.defaultstubignore');

  for (let x = 0; x < fileArr.length; x++) {
    let fileJson = fileArr[x];
    let needsStub = fileJson.needs_stub;
    if (!needsStub) {
      continue;
    }

    let filePath = path.normalize(fileJson.file_path);
    let sourcePath = path.normalize(fileJson.full_path);

    let filePath2 = path.normalize(fileJson.file_path).replace(/\\/g, '/');
    if (gitignore != null && gitignore.inspects(filePath2)) {
      console.log("processProjectFilesInternal gitignore skipping file " + filePath2);
      continue;
    } else if (stubignore != null && stubignore.inspects(filePath2)) {
      console.log("processProjectFilesInternal stubignore skipping file " + filePath2);
      continue;
    }

    //let saveLocation = path.join('.', 'stubble', projectName, filePath);
    // Calculate the md5 hash of the file
    if(!fs.existsSync(sourcePath)){
        //deleted file?
        console.log("File must have been deleted? " + sourcePath + ". Remove from Dexie");
        await dexieDB.deleteStubFile(projectName, filePath);
        // Remove the file from STUBS.stubsData array
        STUBS.stubsData[projectName] = STUBS.stubsData[projectName].filter(stub => stub.full_path !== sourcePath);  
        console.log("after deleted: " );
        console.log(STUBS.stubsData[projectName]);
        continue;
    }
    //console.log("SOURCE PATH EXISTS: " + sourcePath);
    
    const fileBuffer = fs.readFileSync(sourcePath);
    const md5Hash = crypto.createHash('md5').update(fileBuffer).digest('hex');

    // Check if the md5 hash matches the one in the Dexie database
    const foundIndex = STUBS.stubsData[projectName]?.findIndex(stub => stub.file_path === filePath);

    let existingStubFile;
    if (foundIndex >= 0) {
        //console.log("found already");
        // Update existing entry
        existingStubFile = STUBS.stubsData[projectName][foundIndex];
    }else{
        console.log("NOT FOUND NOT FOUND NOT FOUND - SHOULD FIND ALL FILES WHEN MAKING STUBS.stubsData");
        //shouldnt happen
        STUBS.stubsData[projectName].push({
            md5: md5Hash,
            line_count: 0,
            needs_stub: true,
            is_included: true,
            full_path: sourcePath,
            file_path: filePath,
            filename: path.basename(filePath),
            stub_file: ''
        });
        foundIndex = STUBS.stubsData[projectName].length - 1;
    }    
    
    
    if (existingStubFile && existingStubFile.md5 == md5Hash && existingStubFile.stub_file && existingStubFile.stub_file.length > 10 && existingStubFile.md5 != '') {
        //console.log(`Skipping processing for file ${filePath} as md5 hash matches.`);
        continue;
    }
    
    console.log("NO MATCH " + existingStubFile.md5 + " VS " + md5Hash);


    let extName = path.extname(sourcePath).toLowerCase().slice(1);
    
    if (DGRAPH.webfileExtensions.includes(extName)) {
      console.log("getting webfile: " + sourcePath);

      WEBFILE.getFileStub(sourcePath, md5Hash, foundIndex, async function (finalText, theMd5, foundIndex) {
        try {
          //const existingStubFile = await dexieDB.getStubFileByPath(projectName, filePath);             
          //await dexieDB.updateStubFileContent(projectName, filePath, finalText, theMd5);
          STUBS.stubsData[projectName][foundIndex].stub_file = finalText;
          STUBS.stubsData[projectName][foundIndex].md5 = theMd5;
          console.log("stub updated1: ");
          console.log(STUBS.stubsData[projectName][foundIndex]);
          
        } catch (err) {
          console.error('Error updating stub file content in Dexie:', err);
        }
        //console.log("skipping writing to local filesystem");
        /*
        fs.ensureDir(path.dirname(saveLocation))
          .then(() => {
            return fs.writeFile(saveLocation, finalText);
          })
          .then(() => {
            console.log('Webfile Successfully written to file at:', saveLocation);
          })
          .catch(err => {
            console.error('Error writing to file:', err);
          });
          */
      });
    } else {
      console.log("getting CODE FILE: " + sourcePath);
     
      TREESIT.getFileStub(sourcePath, md5Hash, foundIndex, async function (finalText, theMd5, foundIndex) {
        try {
          //const existingStubFile = await dexieDB.getStubFileByPath(projectName, filePath);             
          //await dexieDB.updateStubFileContent(projectName, filePath, finalText, theMd5);
          STUBS.stubsData[projectName][foundIndex].stub_file = finalText;
          STUBS.stubsData[projectName][foundIndex].md5 = theMd5;
          console.log("stub updated2: ");
          console.log(STUBS.stubsData[projectName][foundIndex]);
          

        } catch (err) {
          console.error('Error updating stub file content in Dexie:', err);
        }
        //console.log("skipping writing to local filesystem");
        /*
        fs.ensureDir(path.dirname(saveLocation))
          .then(() => {
            return fs.writeFile(saveLocation, finalText);
          })
          .then(() => {
            console.log('CodeFile Successfully written to file at:', saveLocation);
          })
          .catch(err => {
            console.error('Error writing to file:', err);
          });
          */
      });
    }

    console.log("[progress=" + x.toString() + "|" + totalFiles.toString() + "]");
    updateProgressBar(projectName, x, totalFiles);
  }

  console.log("[progress=" + totalFiles.toString() + "|" + totalFiles.toString() + "]");
  //await updateMD5HashForProcessedFiles(projectName);
  callback();
}


function updateProgressBar(projectName, current, total) {
    const percentage = (current / total) * 100;
    document.querySelector(`.progress-bar-${projectName}`).style.width = percentage + '%';
    
    if(percentage == 100){
        //hide it, done syncing
        $(`.progress-bar-container-${projectName}`).css('display', 'none');
    }
}

/*
function createProgressBarForProject(projectName, projectIndex) {
    const container = document.getElementById('progress-container');
    const projectBar = document.createElement('div');
    projectBar.classList.add(`progress-bar-container-${projectName}`);
    projectBar.innerHTML = `
        <div id="stubprogress_${projectName}" class="project-name">${projectName}</div>
        <div class="progress-bar progress-bar-${projectName}" style="width: 0%"></div>
    `;
    container.appendChild(projectBar);
}
 */
//-------------Check if the md5 of all files match
/*
function updateMD5HashForProcessedFiles(projectName) {
    // Assuming STUBS.stubsData is already loaded
    const projectFiles = STUBS.stubsData[projectName];
    if (projectFiles) {
        projectFiles.forEach(stub => {
            if (stub.needs_stub) {
                let projectFolder;
                for(let p = 0; p < STUBS.projectArr.length; p++){
                    if(STUBS.projectArr[p].project_slug == projectName){
                        projectFolder = STUBS.projectArr[p].folder;
                    }
                }
                const filePath = path.join(projectFolder, stub.file_path);
                if (fs.existsSync(filePath)) {
                    const newMD5 = getMD5HashOfFile(filePath);
                    stub.md5 = newMD5;
                }
            }
        });
    }

    // Save updated stubs data
    //fs.writeFileSync(STUBS.stubsDataPath, JSON.stringify(STUBS.stubsData, null, 2));
}
*/

function readDirRecursive(dirPath, fileList = []) {
    const files = fs.readdirSync(dirPath);

    files.forEach(file => {
        const filePath = path.join(dirPath, file);
        if (fs.statSync(filePath).isDirectory()) {
            fileList = readDirRecursive(filePath, fileList);
        } else {
            fileList.push(filePath);
        }
    });

    return fileList;
}

// Function to compare file hashes
function shouldProcessProject(projectPath, stubsDataArr) {
    const allFiles = readDirRecursive(projectPath);
    // load gitignore here?
    let gitignoreFile = path.join(projectPath, '.gitignore');
    let stubignoreFile = path.join(projectPath, '.stubignore');
    let defaultStubIgnore = STUBS.isPackaged ? path.join(STUBS.appPath, '.defaultstubignore') : path.join(__dirname, '.defaultstubignore');

    let myStubIgnore = null;
    let myGitIgnore = null;
    if (fs.existsSync(gitignoreFile)) {
        let contentOfGitIgnore = readFileWithCache(gitignoreFile);  
        myGitIgnore = gitignoreParser.compile(contentOfGitIgnore);
    } 
    if (fs.existsSync(stubignoreFile)) {
        let contentOfStubIgnore = readFileWithCache(stubignoreFile);  
        myStubIgnore = gitignoreParser.compile(contentOfStubIgnore);
    }else{
        let contentOfDefaultIgnore = readFileWithCache(defaultStubIgnore);  
        myStubIgnore = gitignoreParser.compile(contentOfDefaultIgnore);
    } 
    
    for (const file of allFiles) {
        //console.log("full file: " + file);
        const relativeFilePath = path.relative(projectPath, file);
        //console.log("relativeFilePath: " + relativeFilePath);
        if(myGitIgnore != null && myGitIgnore.inspects(relativeFilePath)){
            //console.log("shouldProcessProject skipping file " + relativeFilePath);
            continue;
        }
        else if(myStubIgnore != null && myStubIgnore.inspects(relativeFilePath)){
            //console.log("shouldProcessProject skipping file " + relativeFilePath);
            continue;
        }          
        
        // Skip over node_modules directories and their contents
        if (file.includes('node_modules') || file.includes('stubble') || file.includes('vendor') || file.includes('.git') || file.includes('stubdiff') || file.includes('nbproject')) {
            //console.log("shouldProcessProject - item blocked because in known library folder: " + file);
            continue;
        }       
        
        //Skip over any unsupported filetype 
        let theExt = path.extname(file);
        if(!STUBS.INCLUDED_FILE_TYPES.includes(theExt)){
            console.log("ext: " + theExt);
            console.log("shouldProcessProject - item blocked because not a included/supported file: " + file);
            continue;            
        }
        
        const fileMD5 = getMD5HashOfFile(file);
        let wasFound = false;
        
        for(let x = 0; x < stubsDataArr.length; x++){
            let apath = stubsDataArr[x]['file_path'];
            let md5 = stubsDataArr[x]['md5'];
            if(apath == relativeFilePath){
                wasFound = true;
                //console.log("found " + apath);
                if(md5 != fileMD5 && stubsDataArr[x]['needs_stub']){
                    console.log("shouldProcessProject MD5 NO MATCH " + relativeFilePath);
                    return true;
                }
            }
        }
        // If file is not in stubsData or MD5 hash is different
        if (!wasFound) {            
            console.log("shouldProcessProject RETURNING TRUE BECAUSE " + relativeFilePath);
            return true; // Indicates that the project needs processing
        }
    }

    return false; // No changes, no need to process
}

function getFileStubPromise(filePath, existingMd5, foundIndex) {
  return new Promise((resolve, reject) => {
    const extName = path.extname(filePath).toLowerCase().slice(1);

    if (DGRAPH.webfileExtensions.includes(extName)) {
      console.log("Getting webfile: " + filePath);
      WEBFILE.getFileStub(filePath, existingMd5, foundIndex, (finalText, theMd5, index) => {
        resolve({
          stubResult: finalText,
          md5: theMd5,
          index: index,
          type: 'webfile'
        });
      });
    } else {
      console.log("Getting CODE FILE: " + filePath);
      TREESIT.getFileStub(filePath, existingMd5, foundIndex, (finalText, theMd5, index) => {
        resolve({
          stubResult: finalText,
          md5: theMd5,
          index: index,
          type: 'codefile'
        });
      });
    }
  });
}

function createStubForSingleFile(projectName, projectPath, filePath) {
    const relativePath = path.relative(projectPath, filePath);
    const fileInfo = getProjectFileInfo(filePath);
    if (fileInfo === null) {
        console.log("Bad file: " + filePath);
        return;
    }

    const filePath2 = path.normalize(relativePath).replace(/\\/g, '/');
    let isIncluded = true;
    if (gitignore !== null && gitignore.denies(filePath2)) {
        isIncluded = false;
    }
    if (stubignore !== null && stubignore.denies(filePath2)) {
        isIncluded = false;
    }

    const foundIndex = STUBS.stubsData[projectName]?.findIndex(stub => stub.full_path === filePath);

    if (foundIndex >= 0) {
        // Update existing entry
        STUBS.stubsData[projectName][foundIndex] = {
            ...STUBS.stubsData[projectName][foundIndex],
            md5: fileInfo.md5_hash,
            line_count: fileInfo.line_count,
            is_included: isIncluded
        };
    } else {
        // Add new entry
        if (!STUBS.stubsData[projectName]) {
            STUBS.stubsData[projectName] = [];
        }
        let theExt = path.extname(filePath).toLowerCase().slice(1);
        const needsStub = DGRAPH.stubExtensions.includes(theExt);

        STUBS.stubsData[projectName].push({
            md5: fileInfo.md5_hash,
            line_count: fileInfo.line_count,
            needs_stub: needsStub,
            is_included: isIncluded,
            full_path: filePath,
            file_path: relativePath,
            filename: path.basename(filePath),
            stub_file: ''
        });
    }

    // Save updated stubs data
    //fs.writeFileSync(STUBS.stubsDataPath, JSON.stringify(STUBS.stubsData, null, 2));
}