const fs = require('fs-extra');
const path = require('path');
const ini = require('ini');
const { ipcRenderer } = require('electron');
const { Readable } = require('stream');
const crypto = require('crypto');
const Parser = require('web-tree-sitter');
const { spawn } = require('child_process');
const gitignoreParser = require('@gerhobbelt/gitignore-parser');
const storage = require('electron-json-storage');
const Mustache = require('mustache');
const chokidar = require('chokidar');
const htmlparser = require('node-html-parser');
const dexieDB = require('./js/dexiedatabase.js');
const mysqlConn = require('./js/mysql_connection.js');
const mysqlLogger = require('./js/mydatabase.js');
const UPOSTGRES = require('./js/postgres_connection.js');
dexieDB.initDatabase();

//config will be removed
var config;
var apiKeys;
var mysqlConfig;
var STUBS = STUBS || {};
STUBS.STUBS_LOADED = false;
STUBS.USE_CONFIG_PROJECTS = false;
STUBS.userDataPath = "";
STUBS.USER_TOKEN = "";
STUBS.LOGGED_IN = false;
STUBS.LOGGED_FIRSTNAME = "";
STUBS.PRO_USER = false;
STUBS.CURRENT_TASK_COUNT = 0;
STUBS.MAXIMUM_TASKS = 50;
STUBS.VERSION_NUMBER = '1.0.11';
STUBS.CUSTOM_API_URLS = new Array();


const taskLogs = {};

// Custom log function
const addLog = (taskId, ...args) => {
    if (!taskLogs[taskId]) {
        taskLogs[taskId] = [];
    }
    let theData = args.map(arg => (typeof arg === 'string' ? arg : JSON.stringify(arg))).join(' ');
    console.log("IN ADDLOG");
    console.log(theData);
    taskLogs[taskId].push(args.map(arg => (typeof arg === 'string' ? arg : JSON.stringify(arg))).join(' '));
};


STUBS.gotosleep = function(ms) {
    return new Promise(resolve => {
        setTimeout(() => {
            //console.clear();
            resolve();
        }, ms);
    });
};
//DEFAULT SETTINGS
STUBS.LOG_STUBCREATION = true;
STUBS.TRY_SIMPLE_CODE_CHANGES = false;
STUBS.TRY_PIECEMEAL_CODE_CHANGES = true;
//formalized simple piecemeal - piecemeal is default
STUBS.APPLY_CHANGES_BY = "piecemeal";
STUBS.APPLY_PARTIAL_NOMESSAGE = true;
STUBS.APPLY_FILE_OVERRIDES = null;
//if less than this number then just do full file replace
STUBS.PIECEMEAL_FULL_REPLACE_LINES = 50;
//if trying to replace original code file block this large, then it can't be a replace
STUBS.PIECEMEAL_TOO_LARGE_BLOCK_LINES = 400;
STUBS.FORCE_LLM_REQUEST_FILES = true;

STUBS.LARGE_PROJECT_FILE_AMOUNT = 150;
STUBS.CODEMIRROR_THEME = "";
STUBS.projectArr = new Array();
STUBS.userOverrideLLMs = {};

STUBS.CLEAR_KEYTAR_ON_STARTUP = false;
STUBS.CLEAR_DEXIE_ON_STARTUP = false;
STUBS.CLEAR_STORAGE_ON_STARTUP = false;
STUBS.TASK_UIDS_TO_STOP = [];

STUBS.ALL_PROJECT_ARR = new Array();

STUBS.MIC_FOCUS_TEXTAREA = "chatgpt-request";
STUBS.MIC_PRETEXT = "";
STUBS.MIC_CURRTEXT = "";
STUBS.MIC_COMMANDTEXT = "";
STUBS.FILE_CACHE = new Map();

STUBS.BLOCKING_UI = false;
STUBS.BLOCKING_MERGE = false;
//supported are ones that generate proper stubs with treesitter, included are ones that are code files but stubs not working 
//'js', 'jsx', 'php', 'sh', 'c', 'cs', 'cpp', 'cc', 'cxx', 'hpp', 
//'hxx','css', 'elm', 'html', 'htm', 'tpl', 'java', 'lua', 'md', 'markdown','
//py', 'rb', 'rs', 'json', 'vue', 'yaml', 'yml', 'dart', 'go', 'ts', 'tsx'

STUBS.SUPPORTED_FILE_TYPES = ['.js', '.sh', '.c', '.cs', '.cpp', '.cc', '.cxx', '.hpp', '.hxx','.css', '.elm', '.html', '.htm', '.tpl', '.go', '.java', '.lua', '.md', '.php', '.py', '.tpl', '.rb', '.rs', '.sv', 
    '.vue', '.yaml', '.dart', '.json', '.ts', '.tsx', '.jsx', '.swift', '.kt'];
STUBS.INCLUDED_FILE_TYPES = ['.js', '.sh', '.c', '.cs', '.cpp', '.css', '.elm', '.html', '.go', '.java', '.lua', '.md', '.php', '.py', '.tpl', '.rb', '.rs', '.sv', '.toml', '.vue', '.yaml', '.dart', '.json', 
    '.ts', '.jsx', '.tsx', '.scss', '.sass', '.less', '.xml', '.sql', '.kt', '.swift', '.m', '.h', '.groovy', '.r', '.pl', '.f90', '.f95', '.f03', '.f08', '.vb', '.asm', '.s', '.bas', '.pas', '.scala', '.clj', 
    '.coffee', '.erl', '.hs', '.ex', '.exs', '.jl', '.nim', '.ml', '.fs', '.fsx', '.ps1', '.bat', '.cmd', '.vbs', '.ahk', '.au3', '.lisp', '.scm', '.rkt', '.tex', '.sty', '.styl', '.cls', '.bib', '.pug', '.haml', '.jade', 
    '.slim', '.liquid', '.hbs', '.ejs', '.njk', '.proto', '.graphql', '.sol', '.tf', '.hcl', '.dockerfile',
    '.blade.php', '.twig', '.mustache', '.jinja', '.jinja2', '.handlebars', '.hbs', '.erb', '.rhtml', '.swig', '.phtml', '.latte', '.volt', '.mako', '.marko', '.dust', '.nunjucks', '.kit', '.dot', '.eco', '.ect', '.jst', '.kt', '.swift'];

const toggleStubMenuItem = document.getElementById('toggle-stub');
let configPath = "";

STUBS.loadSettings = async function(){
    STUBS.projectArr = new Array();
    const apiCredentials = await ipcRenderer.invoke('get-api-credentials');
    
    if(!CHATGPT){
        //needs loading?
        await STUBS.gotosleep(1000);
    }       
    
    if (apiCredentials) {    
        //console.log("API CREDS");
        //console.log(apiCredentials);
        CHATGPT.ANTHROPIC_KEY = apiCredentials['anthropic'];
        CHATGPT.GEMINI_KEY = apiCredentials['gemini'];
        CHATGPT.OPENAI_KEY = apiCredentials['openai'];
        CHATGPT.GROQ_KEY = apiCredentials['groq']; 
        CHATGPT.MISTRAL_KEY = apiCredentials['mistral'];
        STUBS.USER_TOKEN = apiCredentials['user_token'];
        console.log("user token loaded: " + STUBS.USER_TOKEN);
        
        const genericApiKey = apiCredentials.generic;
        
        //console.log("TASK LIST");
        //console.log(genericApiKey);
        
        updateTaskCountAndCheckLimit(genericApiKey);

        
        console.log("MISTRAL KEY " + CHATGPT.MISTRAL_KEY);

        if(CHATGPT.ANTHROPIC_KEY == '' && CHATGPT.GEMINI_KEY == '' && CHATGPT.OPENAI_KEY == '' && CHATGPT.GROQ_KEY == '' && CHATGPT.MISTRAL_KEY == ''){ 
            setTimeout(function(){
                loadSettingsModal(true);
            }, 1000);
        }
        CHATGPT.updateAvailableProviders();
        CHATGPT.getAvailableProviderModels();
        // Authenticate user via IPC
        
        //if (STUBS.USER_TOKEN) {
            STUBS.refreshUserAuthentication();
        //}
       
    }       
    
    storage.get('all_projects', function(error, data) {
        console.log("all_projects");
        console.log(data);    
        if(data){
            console.log("blocking UI");
            STUBS.BLOCKING_UI = true;
            
           /*
            $('#element').block({ 
                message: 'Doing additional task', 
                baseZ: 29999011,
                css: { 
                    border: 'none', 
                    padding: '15px', 
                    backgroundColor: '#6f24f1', 
                    '-webkit-border-radius': '10px', 
                    '-moz-border-radius': '10px', 
                    opacity: .5, 
                    'font-size': '28px',
                    color: '#fff' 
                },
                overlayCSS:  { 
                    backgroundColor: '#000', 
                    opacity:         0.2, 
                    cursor:          'wait' 
                }
            }); 
            */
            $.blockUI({ message: 'Please Wait<br>Indexing Projects and Creating Stubs', baseZ: 29999011,
                css: { 
                    border: 'none', 
                    padding: '15px', 
                    backgroundColor: '#6f24f1', 
                    '-webkit-border-radius': '10px', 
                    '-moz-border-radius': '10px', 
                    opacity: .5, 
                    'font-size': '28px',
                    color: '#fff' 
                },
                overlayCSS:  { 
                    backgroundColor: '#000', 
                    opacity:         0.2, 
                    cursor:          'wait' 
                }, 
            });         
            setTimeout(function(){
                if(STUBS.BLOCKING_UI){
                    console.log("unblocking after 10 sec");
                    $.unblockUI(); 
                    STUBS.BLOCKING_UI = false;
                }
            }, 10000);
        }else{
            console.log("no data");
        }
        
        if (fs.existsSync(configPath)) {
            //STUBS.filesData = JSON.parse(fs.readFileSync(STUBS.filesDataPath));
            config = ini.parse(fs.readFileSync(configPath, 'utf-8'));
            //apiKeys = config.apikeys;
            mysqlConfig = config.mysql;
            if (mysqlConfig && mysqlConfig.server && mysqlConfig.server.length > 0) {
                console.log("TURNING ON DB LOGGING");
                CHATGPT.DB_LOGGING = true;
                mysqlLogger.initDatabase(mysqlConfig);    
            }            
        }            

        STUBS.filesData = {};

        // Load existing file data
        //if (fs.existsSync(STUBS.filesDataPath)) {
        //    STUBS.filesData = JSON.parse(fs.readFileSync(STUBS.filesDataPath));
        //}        
        
      
        if (data && data.all_projects) {
            data.all_projects.forEach(project => {
                console.log(`All Project, Project Name: ${project.name}`);
                console.log(project);
                //console.log(`Project Folder: ${project.folder}`);
                //console.log(`Project Description: ${project.description}`);
                //console.log(`LLM Rules: ${project.llm_rules}`);
                //console.log(`Project Slug: ${project.project_slug}`);
                //console.log('---');
                
                
            });
            
            if(STUBS.USE_CONFIG_PROJECTS){
                console.log("USING CONFIG PROJECTS");
                let projectArr = new Array();
                Object.entries(config.projects).forEach(([projectName, projectPath]) => {
                    projectArr.push({
                        name: projectName,
                        folder: projectPath,
                        project_slug: projectName
                    });
                });
                STUBS.ALL_PROJECT_ARR = projectArr;
                SFILE.createProjectCheckboxes(projectArr);
                STUBS.projectArr = projectArr;
            }else{
                console.log("USING STORAGE PROJECTS");
                console.log(data.all_projects);
                STUBS.ALL_PROJECT_ARR = data.all_projects;
                SFILE.createProjectCheckboxes(data.all_projects);      
                STUBS.projectArr = data.all_projects.map(project => ({
                    name: project.name,
                    folder: project.folder,
                    project_slug: project.project_slug,
                    description: project.description,
                    llm_rules: project.llm_rules
                }));
            }
            doStubCreation(() => {
              console.log('Stub creation completed');
              // Perform any necessary actions after stub creation is complete
              STUBS.STUBS_LOADED = true;    
              console.log(STUBS.stubsData);
              doEmbeddingsCheck();      
            });            
            
        }
        TABS.CREATE_FIRST_TAB();
        updateDayCostEstimate("day");
        //updateDayCostEstimate("week");
    });     
    STUBS.loadCurrentLLMs(true);
        
    STUBS.TRY_SIMPLE_CODE_CHANGES = false;
    //am I saving this
    /*
    storage.get('simple_code_changes', function(error, data) {
        if(data){
            STUBS.TRY_SIMPLE_CODE_CHANGES = data;            
        }else{
            STUBS.TRY_SIMPLE_CODE_CHANGES = false;
        }             
    });
    */
    if(CHATGPT.dexieLogger == null){
        CHATGPT.dexieLogger = dexieDB;
    }
};

STUBS.refreshUserAuthentication = async function(){
    const authData = await ipcRenderer.invoke('authenticate-user', STUBS.USER_TOKEN);
    if (authData) {
        //console.log('User authentication data:', authData);
        if(authData['success'] == "true"){
            console.log("success");
            let fullName = authData['name'];
            let firstName = fullName.split(' ')[0];
            STUBS.LOGGED_FIRSTNAME = firstName;
            if(authData['paid_user'] == 1){
                STUBS.PRO_USER = true;
                $('#upgrade_plan_button').html('<i class="ti ti-check"></i>Pro Version');
            }
            $('#login_or_name').text("Hello, " + firstName);
            $('#menu-logout').css('display', 'block');
        }else{
            console.log("not success");
            console.log(authData['success']);
        }
        // Handle the response data (logged_in, pro_user, name, email)
        // Update UI or perform actions based on user's Free/Pro status
    } else {
        console.error('User authentication failed');
    }    
};

ipcRenderer.invoke('get-user-app-paths').then(paths => {
    console.log("paths");
    console.log(paths);
    STUBS.userDataPath = paths.userDataPath;
    STUBS.appPath = paths.appPath;
    STUBS.isPackaged = paths.isPackaged;
    STUBS.chromePath = paths.chromePath;
    STUBS.appVersion = paths.appVersion;
    STUBS.platform = paths.platform;
    
    //console.log("chrome path is: " + STUBS.chromePath);
    
    if (STUBS.platform === 'darwin') {
      $('body').addClass('mac-os');
    }        
    
    configPath = path.join(STUBS.appPath, '.config.ini');
    if (STUBS.isPackaged) {        
        STUBS.MAXIMUM_TASKS = 7;
    } else {
        $('#testing-container').css('display', 'block');
        $('#milestone_planner_menu').css('display', 'block');
        $('.terminal-container').css('display', 'block');
        $('.planner-container').css('display', 'block');        
        $('.debug-container').css('display', 'block');
        $('#debugger_menu').css('display', 'block');       
    }
    storage.setDataPath(STUBS.userDataPath);
    STUBS.loadSettings();
});

STUBS.loadCurrentLLMs = function(loadDefaultProjects){
    storage.get('stubs_settings', function(error, stubsSettings) {
        if (error) throw error;    
        console.log("STUBS SETTINGS ");
        console.log(stubsSettings);
        STUBS.userOverrideLLMs = {
            'request_relevant_files' : "",
            'request_relevant_line_numbers' : "",
            'request_relevant_stub_lines' : "",
            'do_new_programming_task' : "",
            'do_additional_programming_task' : "",
            'formalize_code_changes' : "",
            'request_file_descriptions' : "",
            'prune_unlikely_project_files' : "",
            'single_file_full_change' : ""
        };
        
        if (stubsSettings.llm_request_relevant_files != "recommended" && stubsSettings.llm_request_relevant_files != "") {
            STUBS.userOverrideLLMs['request_relevant_files'] = stubsSettings.llm_request_relevant_files;
        }        
        if (stubsSettings.llm_request_relevant_stub_lines != "recommended" && stubsSettings.llm_request_relevant_stub_lines != "") {
            STUBS.userOverrideLLMs['request_relevant_stub_lines'] = stubsSettings.llm_request_relevant_stub_lines;
            STUBS.userOverrideLLMs['request_relevant_line_numbers'] = stubsSettings.llm_request_relevant_stub_lines;
        }
        
        if (stubsSettings.llm_do_new_programming_task != "recommended" && stubsSettings.llm_do_new_programming_task != "") {
            STUBS.userOverrideLLMs['do_new_programming_task'] = stubsSettings.llm_do_new_programming_task;
        }
        
        if (stubsSettings.llm_formalize_code_changes != "recommended" && stubsSettings.llm_formalize_code_changes != "") {
            STUBS.userOverrideLLMs['formalize_code_changes'] = stubsSettings.llm_formalize_code_changes;
        }
        
        if (stubsSettings.llm_prune_unlikely_project_files != "recommended" && stubsSettings.llm_prune_unlikely_project_files != "") {
            STUBS.userOverrideLLMs['prune_unlikely_project_files'] = stubsSettings.llm_prune_unlikely_project_files;
            STUBS.userOverrideLLMs['single_file_full_change'] = stubsSettings.llm_prune_unlikely_project_files;
            STUBS.userOverrideLLMs['request_file_descriptions'] = stubsSettings.llm_prune_unlikely_project_files;
        }        
        console.log("USER OVERRIDE LLMS");
        /*
        stubsSettings.llm_request_relevant_files;
        stubsSettings.llm_request_relevant_stub_lines;
        stubsSettings.llm_do_new_programming_task;
        stubsSettings.llm_formalize_code_changes;
        stubsSettings.llm_prune_unlikely_project_files;
        */
        STUBS.CODEMIRROR_THEME = stubsSettings.codemirror_theme;
        if(typeof(stubsSettings.apply_changes_by) !== 'undefined'){
            STUBS.APPLY_CHANGES_BY = stubsSettings.apply_changes_by;           
        }
        
        if(typeof(stubsSettings.custom_api_urls) !== 'undefined'){
            //http://localhost:1234/v1/
            //meta-llama-3.1-8b-instruct-q4_k_m
            //https://api.deepseek.com/v1
            //deepseek-chat
            //https://openrouter.ai/api/v1
            //qwen/qwen-2.5-72b-instruct
            STUBS.CUSTOM_API_URLS = stubsSettings.custom_api_urls;           
        }
        
        console.log("CUSTOM API URLS");
        console.log(STUBS.CUSTOM_API_URLS);
        
        console.log("apply changes by " + STUBS.APPLY_CHANGES_BY);
                
        // Load default projects
        if(loadDefaultProjects){
            console.log("default checked projects");
            console.log(stubsSettings.default_projects);        
            
            if (stubsSettings.default_projects) {
              SFILE.loadCheckedProjects(stubsSettings.default_projects);
            }
        }
    });    
};


var doStubCreation = async function(callback){
    console.log("doing stub creation with ");
    console.log(STUBS.projectArr);
    
    //use this instead when ready    
    STUBS.stubsData = {};
    for(const project of STUBS.projectArr) {   
        console.log("project slug : " + project.project_slug);
        try{
            console.log("loading from dexie");
            STUBS.stubsData[project.project_slug] = await dexieDB.getStubFilesFromDexie(project.project_slug);
            console.log("after from dexie");            
        }catch(exxx){
            console.log("could not load dexie data: " + project.project_slug);
            console.log(exxx);
            STUBS.stubsData[project.project_slug] = new Array();
        }                
    }      
    
    console.log("Stubs loaded from Dexie");
    console.log(STUBS.stubsData);
    


        
        const possibleProjects = STUBS.projectArr.map(project => project.project_slug);
        let projectQueue = new Array();
        for(let p = 0; p < STUBS.projectArr.length; p++){
            let aProject = STUBS.projectArr[p];
            await createStubsForProject(aProject, STUBS.stubsData);
            console.log("Full stub files object for project: " + aProject.project_slug + " with directory files added");
            let projectSlug = aProject.project_slug;
            console.log(STUBS.stubsData[projectSlug]);      
            
            const projectPath = aProject.folder;
            if (shouldProcessProject(projectPath, STUBS.stubsData[projectSlug])) {
                console.log("Processing Project: " + projectSlug);
                projectQueue.push(projectSlug);
            }else{
                console.log("stubs loaded 1");
                console.log("Skipping Project: " + projectSlug);   
                //hide syncing 
                $(`#project-syncing-${projectSlug}`).css('display', 'none');
            }
        }        
        
        if(projectQueue.length > 0){

            // Start processing for the first project
            const firstProject = projectQueue[0];
            processProjectFiles(firstProject, projectQueue, async () => {
              // All projects have been processed, invoke the callback
              callback();
              STUBS.STUBS_LOADED = true;
              console.log("stubs loaded 2");

              for(let p = 0; p < STUBS.projectArr.length; p++){
                  let aProject = STUBS.projectArr[p];
                  let projectSlug = aProject.project_slug;
                  console.log("hiding sync " + projectSlug);
                  $(`#project-syncing-${projectSlug}`).css('display', 'none');
                  console.log("saving to dexie: ");
                  console.log(STUBS.stubsData[projectSlug]);
                  await dexieDB.saveStubFilesToDexie(projectSlug, STUBS.stubsData[projectSlug]);
              }
            });
        }else{
            console.log("stubs loaded 3");
            callback();
            STUBS.STUBS_LOADED = true;      
            for(let p = 0; p < STUBS.projectArr.length; p++){
                let aProject = STUBS.projectArr[p];
                let projectSlug = aProject.project_slug;
                $(`#project-syncing-${projectSlug}`).css('display', 'none');
            }            
        }
    
};


async function doEmbeddingsCheck(){
    console.log("Starting Embeddings update");
    await EMBED.buildReadyArray();
    $.unblockUI(); 
    STUBS.BLOCKING_UI = false;
    //refreshing the tribute with a click
    //doEmbeddingsCheck
    $('#chatgpt-request').trigger('click');

}


document.getElementById('min-btn').addEventListener('click', () => {
  ipcRenderer.send('minimizeApp');
});

document.getElementById('max-btn').addEventListener('click', () => {
  ipcRenderer.send('maximizeRestoreApp');
});

document.getElementById('close-btn').addEventListener('click', () => {
  ipcRenderer.send('closeApp');
});

ipcRenderer.on('storeDebugData', (event, debugData) => {
  dexieDB.saveDebugData(debugData);
});


ipcRenderer.on('updateUserToken', (event, userToken) => {
    console.log("updating user token: " + userToken);
    STUBS.USER_TOKEN = userToken;
    STUBS.refreshUserAuthentication();
});


ipcRenderer.on('transcriptionData', (event, transcriptionData) => {
    let updateType = transcriptionData.update_type;
    let newText = transcriptionData.transcription;
    
    if (typeof newText !== 'string') {
        console.log("BAD NEWTEXT ");
        console.log(newText);
        console.log(transcriptionData);
        return;
    }
    let nonspeechTokens = ['[BLANK_AUDIO]', '[BACKGROUND_NOISE]', '[CAMERA_MUSIC]'];
    let containsNonspeechToken = nonspeechTokens.some(token => newText.indexOf(token) !== -1);
    if(nonspeechTokens.some(token => newText.includes(token))){
        return;
    }
    console.log("update type: " + updateType);
    console.log("newText: " + newText);
    if(updateType == 'silence'){
        STUBS.MIC_PRETEXT += STUBS.MIC_CURRTEXT;
        STUBS.MIC_CURRTEXT = "";
        STUBS.MIC_COMMANDTEXT = "";
        return;
    }
    if (newText.toLowerCase().includes("stubs") || newText.toLowerCase().includes("stubbs")) {
        // Clear current text and wait for command word
        STUBS.MIC_CURRTEXT = "";
        STUBS.MIC_PRETEXT += STUBS.MIC_CURRTEXT;
        STUBS.MIC_COMMAND_MODE = true;
        console.log("turning on command mode");
        return;
    }

    if (STUBS.MIC_COMMAND_MODE) {
        STUBS.MIC_COMMANDTEXT += newText;
        // Check for command words
        if (STUBS.MIC_COMMANDTEXT.toLowerCase().includes("pause")) {
            console.log("INTERRUPT MIC NOWWW");
            STUBS.MIC_PAUSED = true;
            STUBS.MIC_COMMAND_MODE = false;
            STUBS.MIC_COMMANDTEXT = ""; // Clear the command text
        } else if (STUBS.MIC_COMMANDTEXT.toLowerCase().includes("resume")) {
            console.log("RESUMING Mic");
            STUBS.MIC_PAUSED = false;
            STUBS.MIC_COMMAND_MODE = false;
            STUBS.MIC_COMMANDTEXT = ""; // Clear the command text
        } else if (STUBS.MIC_COMMANDTEXT.toLowerCase().includes("add tab")) {
            // Trigger add tab functionality
            //addNewTab();
            STUBS.MIC_COMMANDTEXT = ""; // Clear the command text
            $('.add_new_tab').trigger('click');
        }        
        return;
    }

    if (STUBS.MIC_PAUSED) {
        console.log("Mic is interrupted");
        return;
    }    
    
    if(updateType == 'complete'){
        if(newText.containsNonspeechToken){
            nonspeechTokens.forEach(token => {
                if (newText.includes(token)) {
                    newText = newText.replace(new RegExp(token, 'g'), '');
                    console.log("REPLAED " + token + " IN TEXT");
                }
            });           
        }
        STUBS.MIC_CURRTEXT = newText;
        $('#' + STUBS.MIC_FOCUS_TEXTAREA).val(STUBS.MIC_PRETEXT + STUBS.MIC_CURRTEXT);
    }else if(STUBS.MIC_CURRTEXT.length < newText.length){
        console.log("UPDATE IS OVERRIDING TEXT ");
        console.log(newText);
        //STUBS.MIC_CURRTEXT = newText;
    }
    //let newVal;
    
});




async function updateDayCostEstimate(period = "day") {
  console.log("updating cost");

  const now = new Date();
  let startDate, endDate;

  switch (period) {
    case "week":
      startDate = new Date(now.getTime() - 7 * 24 * 60 * 60 * 1000);
      endDate = now;
      break;
    case "month":
      startDate = new Date(now.getTime() - 30 * 24 * 60 * 60 * 1000);
      endDate = now;
      break;
    default:
      startDate = new Date(now.getFullYear(), now.getMonth(), now.getDate());
      endDate = new Date(startDate.getTime() + 24 * 60 * 60 * 1000 - 1);
  }

  let totalCost = 0;
  console.log("cost avail models");
  console.log(CHATGPT.AVAIL_MODELS);
  console.log("startdate");
  console.log(startDate);
  console.log("endDate");
  console.log(endDate);

  for (const fullModel of CHATGPT.AVAIL_MODELS) {
    const totalUsedTokens = await dexieDB.getTotalUsedTokens(fullModel, startDate, endDate);
    const inputTokens = totalUsedTokens.input_tokens;
    const outputTokens = totalUsedTokens.output_tokens;
    const cost = COST.getTokenCost(fullModel, inputTokens, outputTokens);
    totalCost += cost;
  }

  const costElementId = "today_cost";
  document.getElementById(costElementId).textContent = `$${totalCost.toFixed(2)}`;
}

function updateTaskCountAndCheckLimit(genericApiKey) {
  let taskCount = 0;
  const now = new Date();
  const userDayStart = new Date(now.getFullYear(), now.getMonth(), now.getDate());
  const userDayEnd = new Date(userDayStart.getTime() + 24 * 60 * 60 * 1000 - 1);

  //console.log("User day start:", userDayStart);
  //console.log("User day end:", userDayEnd);

  for (const task of genericApiKey) {
    if(!('full_date' in task)){
        //console.log("task does not have full_date");
        continue;
    }  
      
    const taskDate = new Date(task.full_date);
    //console.log("Task date:", taskDate);

    if (taskDate >= userDayStart && taskDate <= userDayEnd) {
      //console.log("Task is within the user's day");
      taskCount++;
    } else {
      //console.log("Task is outside the user's day");
    }
  }
  
  console.log("Task count:", taskCount);
  $('#task_count').text(taskCount);
  STUBS.CURRENT_TASK_COUNT = taskCount;
  if(STUBS.CURRENT_TASK_COUNT > STUBS.MAXIMUM_TASKS){
      return true;
  }else{
      return false;
  }
}

async function exceededTaskLimit() {
    const apiCredentials = await ipcRenderer.invoke('get-api-credentials');
    if (apiCredentials) {
        const genericApiKey = apiCredentials.generic;
        
        //console.log("TASK LIST EXCEED? ");
        //console.log(genericApiKey);
        
        let reachedLimit = updateTaskCountAndCheckLimit(genericApiKey);
        if (reachedLimit && !STUBS.PRO_USER) {
            //alert("CURRENT " + STUBS.CURRENT_TASK_COUNT + " is more than " + STUBS.MAXIMUM_TASKS);
            showProVersionModal();
            return true;
        }
    }
    return false;
}

function showProVersionModal() {
    if ($('#modal_pro_version').length > 0) {
        $('#modal_pro_version').remove();
    }
    
    let proVersionModalBody = fs.readFileSync(path.join(STUBS.appPath, 'views', 'modal_pro_version.html'), 'utf-8');
    let proVersionModal = Mustache.render(proVersionModalBody, {});

    $('body').append(proVersionModal);

    setTimeout(function () {
        MicroModal.show('modal_pro_version', {
            debugMode: true,
            disableScroll: true,
            onShow: function (modal) { },
            onClose: function (modal) { },
            awaitCloseAnimation: true
        });
    }, 100);
}

function generateUID() {
    var d = new Date().getTime(); // Timestamp
    var d2 = (process.hrtime && process.hrtime().valueOf() && (process.hrtime().valueOf() * 1000)) || 0; // Time in microseconds since process start or 0 if unsupported

    return 'xxxxxxxxxx'.replace(/[xy]/g, function(c) {
        var r = Math.random() * 16; // Random number between 0 and 16
        if (d > 0) { // Use timestamp until depleted
            r = (d + r) % 16 | 0;
            d = Math.floor(d / 16);
        } else { // Use microseconds since process start if supported
            r = (d2 + r) % 16 | 0;
            d2 = Math.floor(d2 / 16);
        }
        return r.toString(16);
    });
}

function comparePaths(path1, path2, allowShorterPaths = false) {
  const normalizedPath1 = path.normalize(path1).replace(/\\/g, '/');
  const normalizedPath2 = path.normalize(path2).replace(/\\/g, '/');

  const pathPieces1 = normalizedPath1.split('/').filter(piece => piece !== '');
  const pathPieces2 = normalizedPath2.split('/').filter(piece => piece !== '');

  const len1 = pathPieces1.length;
  const len2 = pathPieces2.length;

  if (!allowShorterPaths && len1 !== len2) {
    return false;
  }

  const minLen = Math.min(len1, len2);

  for (let i = 1; i <= minLen; i++) {
    if (pathPieces1[len1 - i] !== pathPieces2[len2 - i]) {
      return false;
    }
  }

  return true;
}

function arrayHasPath(pathArr, path2){
    for(let x = 0; x < pathArr.length; x++){
        if(comparePaths(pathArr[x], path2, true)){
            return true;
        }
    }    
    return false;
}

function arrayGetPath(pathArr, path2){
    for(let x = 0; x < pathArr.length; x++){
        if(comparePaths(pathArr[x], path2, false)){
            return pathArr[x];
        }        
    }    
    for(let y = 0; y < pathArr.length; y++){      
        if(comparePaths(pathArr[y], path2, true)){
            return pathArr[y];
        }
    }       
    
    return null;
}


function getStorageData(storageKey) {
    return new Promise((resolve, reject) => {
        storage.get(storageKey, function(error, data) {
            if (error) {
                reject(error);
            } else {
                resolve(data);
            }
        });
    });
}


var escapeRegExp = function(string) {
    return string.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, "\\$1");
};

var replaceAll = function(string, find, replace) {
  return string.replace(new RegExp(escapeRegExp(find), 'g'), replace);
};

function createTimeoutPromise(ms) {
  return new Promise((_, reject) => {
    setTimeout(() => reject(new Error(`Timeout after ${ms} ms`)), ms);
  });
}

if(STUBS.CLEAR_KEYTAR_ON_STARTUP){
    ipcRenderer.invoke('clear-all-keytar-data');
}

if(STUBS.CLEAR_DEXIE_ON_STARTUP){
    dexieDB.clearDatabase();
}

if(STUBS.CLEAR_STORAGE_ON_STARTUP){
  storage.clear(function(error) {
    if (error) throw error;
    console.log('All data cleared from electron-json-storage');
  });    
}

