

async function main() {
  const TransformersApi = Function('return import("@xenova/transformers")')();    
  const { pipeline } = await TransformersApi;
  // Load the pre-trained model for feature extraction
  const model = "Xenova/all-MiniLM-L6-v2";

  // Function to generate embeddings for the documents
  async function generateEmbeddings(docs) {
    const generateEmbedding = await pipeline("feature-extraction", model);
    const embeddings = await Promise.all(
      docs.map(async (doc) => {
        const content = `${doc.filename}\n${doc.description}\n${doc.dependencies.join("\n")}`;
        const output = await generateEmbedding(content, {
          pooling: "mean",
          normalize: true,
        });
        return Array.from(output.data);
      })
    );
    return embeddings;
  }

  // Sample documents (code files with metadata)
    // Sample documents (code files with metadata)
    const documents = [
      {
        filename: "utility.js",
        description: "This file contains utility functions for string manipulation.",
        dependencies: [
          "file1.js calls function_x from utils.js",
          "file2.js calls function_y from file1.js",
        ],
      },
      {
        filename: "authorize.js",
        description: "This file handles user authentication and authorization.",
        dependencies: [
          "authorize.js calls function_y from utility.js",
          "authorize.js calls function_z from utility.js",
        ],
      },
      {
        filename: "ui_handlers.js",
        description: "This file handles setting up the UI.",
        dependencies: [
          "ui_handlers.js calls get_widgets() from utility.js",
          "ui_handlers.js calls get_layout() from utility.js",
        ],
      },  
    ];

  // Function to find the most similar documents to a query
  async function findMostSimilarDocuments(query, embeddings, topK = 3) {
    const generateEmbedding = await pipeline("feature-extraction", model);
    const queryEmbedding = await generateEmbedding(query, {
      pooling: "mean",
      normalize: true,
    });
    const similarities = embeddings.map((embedding) =>
      cosineSimilarity(Array.from(queryEmbedding.data), embedding)
    );
    const mostSimilarIndices = findTopKIndices(similarities, topK);
    return mostSimilarIndices.map((index) => documents[index]);
  }

  // Helper function to calculate cosine similarity between two vectors
  function cosineSimilarity(a, b) {
    const dotProduct = a.reduce((sum, val, idx) => sum + val * b[idx], 0);
    const normA = Math.sqrt(a.reduce((sum, val) => sum + val * val, 0));
    const normB = Math.sqrt(b.reduce((sum, val) => sum + val * val, 0));
    return dotProduct / (normA * normB);
  }

  // Helper function to find the indices of the top K values in an array
  function findTopKIndices(arr, k) {
    const sortedIndices = arr.map((val, idx) => idx).sort((a, b) => arr[b] - arr[a]);
    return sortedIndices.slice(0, k);
  }

  // Example usage
  const embeddings = await generateEmbeddings(documents);
  const query = "Find files related to building the UI";
  const mostSimilarDocuments = await findMostSimilarDocuments(query, embeddings);
  console.log("Most similar documents:", mostSimilarDocuments);
}

main().catch(console.error);