const { execSync } = require('child_process');
let previousProcesses = new Set();

function listProcesses() {
  const output = execSync('wmic process get ProcessId,ExecutablePath,CommandLine /format:list', { encoding: 'utf8' });
  const processes = output.trim().split(/\n\s*\n/);
  let validCount = 0;
  processes.forEach(process => {
    const lines = process.trim().split('\n');
    const processIdLine = lines.find(line => line.startsWith('ProcessId='));
    const executablePathLine = lines.find(line => line.startsWith('ExecutablePath='));
    const commandLineLine = lines.find(line => line.startsWith('CommandLine='));

    const processId = processIdLine ? processIdLine.split('=')[1] : '';
    const executablePath = executablePathLine ? executablePathLine.split('=')[1] : '';
    const commandLine = commandLineLine ? commandLineLine.split('=')[1] : '';
    
    
    const excludedProcesses = [
      'conhost.exe','svchost.exe','explorer.exe','taskhost.exe','winlogon.exe','csrss.exe'
    ];

    if (excludedProcesses.some(process => executablePath.toLowerCase().includes(process))) {
      return;
    } 
    if(executablePath.trim() == '' && commandLine.trim() == ''){
        console.log(`SKIPPED PID: ${processId}`);
        return;
    }

    console.log(`PID: ${processId}`);
    console.log(`Executable Path: ${executablePath}`);
    console.log(`Command Line: ${commandLine}`);
    console.log('-----------------------------------');
    validCount++;
  });
  console.log("total listed " + validCount);
}



function listLinuxProcesses() {
  let command = '';
  let processIdIndex = 0;
  let executablePathIndex = 1;

  if (os.platform() === 'darwin') {
    // macOS
    command = 'ps -eo pid,command';
  } else if (os.platform() === 'linux') {
    // Linux
    command = 'ps -eo pid,cmd';
    executablePathIndex = 1;
  } else {
    console.log('Unsupported operating system');
    return;
  }

  const output = execSync(command, { encoding: 'utf8' });
  const processes = output.trim().split('\n').slice(1); // Remove header line

  const currentProcesses = new Set();

  processes.forEach(processLine => {
    const fields = processLine.trim().split(/\s+/);
    const processId = fields[processIdIndex];
    const executablePath = fields.slice(executablePathIndex).join(' ');

    // Exclude specific system processes
    const excludedProcesses = [
      '/sbin/launchd',
      '/usr/sbin/syslogd',
      '/usr/libexec/UserEventAgent',
      '/System/Library/CoreServices/Finder.app/Contents/MacOS/Finder',
      '/usr/libexec/kextd',
      'kthreadd',
      'rcu_sched',
      'migration/0'
    ];

    if (excludedProcesses.some(process => executablePath.includes(process))) {
      return;
    }

    currentProcesses.add(processId);

    if (!previousProcesses.has(processId)) {
      // New process detected
      console.log(`New Process Detected:`);
      console.log(`PID: ${processId}`);
      console.log(`Executable Path: ${executablePath}`);
      console.log('-----------------------------------');
    }
  });

  previousProcesses = currentProcesses;
}

listProcesses();