const path2 = require('path');
const Parser2 = require('web-tree-sitter');
const fs2 = require('fs-extra');

var TREESIT = {
  parser: null,
  fileLines: new Array(),
  fileText : "",
  currentNodes: null,
  conDebug: false,
  parsers: {}, // Store a separate parser for each language
  badParsers : new Set(),
  parserInitialized : false,
  
  initializeParser: async function (languageName) {
    if (typeof(STUBS) === 'undefined') {
      var STUBS = {};
      STUBS.isPackaged = false;
    }
    try {
      if (!this.parserInitialized) {
        await Parser2.init();
        this.parserInitialized = true;
      }
      if (!this.parsers[languageName]) {
        let parser = new Parser2();
        let myAppPath = STUBS.isPackaged ? STUBS.appPath : __dirname;
        let languageToFile = {
          'javascript': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-javascript_v2.wasm'),
          'bash': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-bash.wasm'),
          'c': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-c_v2.wasm'),
          'c_sharp': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-csharp_v2.wasm'),
          'cpp': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-cpp_v2.wasm'),
          'css': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-css_v2.wasm'),
          'elm': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-elm_v2.wasm'),
          'html': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-html_v3.wasm'),
          'java': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-java_v2.wasm'),
          'json': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-json_v2.wasm'),
          'lua': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-lua_v2.wasm'),
          'markdown': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-markdown_v2.wasm'),
          'php': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-php_v4.wasm'),
          'python': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-python.wasm'),
          'ruby': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-ruby_v5.wasm'),
          'rust': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-rust_v2.wasm'),
          'typescript': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-typescript_v2.wasm'),
          'tsx': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-tsx_v2.wasm'),
          'swift': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-swift_v2.wasm'),
          'kotlin': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-kotlin_v2.wasm')
          // Add more languages as needed
        };
        let languageFilePath = languageToFile[languageName];
        if (!languageFilePath) {
          console.log("Unknown language: " + languageName);
          this.badParsers.add(languageName);
          return null;
        }
        console.log("Loading " + languageName + " wasm from " + languageFilePath);
        let lang = await Parser2.Language.load(languageFilePath);
        parser.setLanguage(lang);
        this.parsers[languageName] = parser;
      }
      return this.parsers[languageName];
    } catch (error) {
      console.error('Error initializing web-tree-sitter for language ' + languageName + ':', error);
      this.badParsers.add(languageName);
      return null;
    }
  },
  parseAnyLanguage: async function (fileData, theExt, doSyntaxCheck, callback) {
    let languageName = this.getLanguageByExt(theExt);
    if (!languageName) {
      console.log("Unknown language extension: " + theExt);
      return;
    }

    // If the parser for this language is marked as bad, skip parsing
    if (this.badParsers.has(languageName)) {
      console.log(`Parser for language ${languageName} is marked as bad. Skipping parsing.`);
      return;
    }

    // Initialize the parser for the language
    let parser = await this.initializeParser(languageName);
    if (!parser) {
      console.log(`Failed to initialize parser for language ${languageName}`);
      return;
    }

    this.fileText = fileData;
    this.fileLines = fileData.split(/\r?\n/);
    const tree = parser.parse(fileData);

    if (doSyntaxCheck) {
      let errObject = {
        has_error: false,
        start_line: -1,
        end_line: -1
      };
      if (tree.rootNode.hasError()) {
        const errorNode = this.findFirstErrorNode(tree.rootNode);
        if (errorNode) {
          errObject = {
            has_error: true,
            start_line: errorNode.startPosition.row,
            end_line: errorNode.endPosition.row
          };
        } else {
          errObject = {
            has_error: true,
            start_line: -1,
            end_line: -1
          };
        }
      }
      callback(errObject);
      return;
    }

    this.currentNodes = this.traverseTree(tree.rootNode, parseInt(tree.rootNode.startPosition.row), parseInt(tree.rootNode.endPosition.row));
    if (this.conDebug) {
      console.log("current nodes 2");
      console.log(JSON.stringify(this.currentNodes, null, 2));
    }
    callback(this.currentNodes);
  },  
  /*
  parseAnyLanguage: async function (fileData, theExt, doSyntaxCheck, callback) {
    let langSetter = null;
    if(typeof(STUBS) === 'undefined'){
        var STUBS = {};
        STUBS.isPackaged = false;
    }    
    let myAppPath = STUBS.isPackaged ? STUBS.appPath : __dirname;
    let languageToFile = { 
      'base' : path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-javascript_v2.wasm'),
      'javascript' : path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-javascript_v2.wasm'),      
      'bash' : path2.join(myAppPath, 'jslib', 'wasm',  'tree-sitter-bash.wasm'),
      'c': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-c_v2.wasm'),
      'c_sharp': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-csharp_v2.wasm'),
      'cpp': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-cpp_v2.wasm'),
      'css': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-css_v2.wasm'),
      'elm': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-elm_v2.wasm'),
      'embedded_template': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-embedded_template.wasm'),
      'go': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-go_v2.wasm'),
      'tpl': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-smarty.wasm'),
      'html': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-html_v3.wasm'),
      'java': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-java_v2.wasm'),
      'json': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-json_v2.wasm'),
      'lua': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-lua_v2.wasm'),
      'markdown': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-markdown.wasm'),
      'php': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-php_v4.wasm'),
      'python': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-python.wasm'),
      'ruby': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-ruby_v5.wasm'),
      'rust': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-rust_v2.wasm'),
      'systemrdl': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-systemrdl.wasm'),
      'toml': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-toml.wasm'),
      'vue': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-vue.wasm'),
      'dart': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-dart_v2.wasm'),  
      'yaml': path2.join(myAppPath, 'jslib', 'wasm', 'tree-sitter-yaml.wasm'),
      'typescript': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-typescript_v2.wasm'),
      'tsx': path2.join(myAppPath, 'jslib', 'wasm', 'treesitter-tsx_v2.wasm')
    };      
    console.log("parser setting language theextension is: " + theExt);
    if (theExt == 'js') {
       
      langSetter = await Parser2.Language.load(languageToFile['javascript']);
    } else if (theExt == 'php') {
      langSetter = await Parser2.Language.load(languageToFile['php']);
    } else if (theExt == 'sh') {
      langSetter = await Parser2.Language.load(languageToFile['bash']);
    } else if (theExt == 'c') {
      langSetter = await Parser2.Language.load(languageToFile['c']);
    } else if (theExt == 'cs') {
      langSetter = await Parser2.Language.load(languageToFile['c_sharp']);
    } else if (theExt == 'cpp' || theExt == 'cc' || theExt == 'cxx' || theExt == 'hpp' || theExt == 'hxx') {
      langSetter = await Parser2.Language.load(languageToFile['cpp']);
    } else if (theExt == 'css') {
      langSetter = await Parser2.Language.load(languageToFile['css']);
    } else if (theExt == 'elm') {
      langSetter = await Parser2.Language.load(languageToFile['elm']);
    } else if (theExt == 'html' || theExt == 'htm') {
      langSetter = await Parser2.Language.load(languageToFile['html']);
    } else if (theExt == 'tpl') {
      langSetter = await Parser2.Language.load(languageToFile['tpl']);
    }else if (theExt == 'java') {
      langSetter = await Parser2.Language.load(languageToFile['java']);
    } else if (theExt == 'lua') {
      langSetter = await Parser2.Language.load(languageToFile['lua']);
    } else if (theExt == 'md' || theExt == 'markdown') {
      langSetter = await Parser2.Language.load(languageToFile['markdown']);
    } else if (theExt == 'py') {
      langSetter = await Parser2.Language.load(languageToFile['python']);
    } else if (theExt == 'rb') {
      langSetter = await Parser2.Language.load(languageToFile['ruby']);
    } else if (theExt == 'rs') {
      langSetter = await Parser2.Language.load(languageToFile['rust']);
    } else if (theExt == 'toml') {
      langSetter = await Parser2.Language.load(languageToFile['toml']);
    } else if (theExt == 'vue') {
      langSetter = await Parser2.Language.load(languageToFile['vue']);
    } else if (theExt == 'yaml' || theExt == 'yml') {
      langSetter = await Parser2.Language.load(languageToFile['yaml']);
    } else if (theExt == 'json') {
      langSetter = await Parser2.Language.load(languageToFile['json']);
    } else if (theExt == 'dart') {
      langSetter = await Parser2.Language.load(languageToFile['dart']);
    } else if (theExt == 'go') {
      langSetter = await Parser2.Language.load(languageToFile['go']);
    } else if (theExt == 'ts') {
      langSetter = await Parser2.Language.load(languageToFile['typescript']);
    } else if (theExt == 'tsx') {
      langSetter = await Parser2.Language.load(languageToFile['tsx']);
    } else {
      console.log("Unknown language");
      return;
    }
    this.parser.setLanguage(langSetter);

    //let file1 = "C:\\wamp\\www\\stubs\\stubs-ai-assistant\\handlers.js";
    //let fileData = fs.readFileSync(file1, 'utf-8');
    
    this.fileText = fileData;
    this.fileLines = new Array();    
    this.fileLines = fileData.split(/\r?\n/);
    const tree = this.parser.parse(fileData);
    
    if(doSyntaxCheck){
        let errObject = {
            has_error: false,
            start_line: -1,
            end_line: -1
        };
        if (tree.rootNode.hasError()) {
            const errorNode = this.findFirstErrorNode(tree.rootNode);
            if (errorNode) {
              errObject = {
                has_error: true,
                start_line: errorNode.startPosition.row,
                end_line: errorNode.endPosition.row
              };
            } else {
              errObject = {
                has_error: true,
                start_line: -1,
                end_line: -1
              };
            }
        } 
        
        return errObject;
       
    }
    
    //console.log("full tree");
    //console.log(JSON.stringify(tree.rootNode, null, 2));
    //console.log("the sitter");

    this.currentNodes = this.traverseTree(tree.rootNode, parseInt(tree.rootNode.startPosition.row), parseInt(tree.rootNode.endPosition.row));
    //console.log(this.currentNodes);
    //console.log(JSON.stringify(this.currentNodes, null, 2));
    if(this.conDebug){
        console.log("current nodes 2");
        console.log(JSON.stringify(this.currentNodes, null, 2));    
    }
    callback(this.currentNodes);
  },  
  getNodeName: function (node) {
      if (node.type === 'function_declaration') {
        // For a function declaration (e.g., function myFunction() {...}),
        // find the identifier node that represents the function name
        const identifierNode = node.firstNamedChild;
        if (identifierNode && identifierNode.type === 'identifier') {
          return identifierNode.text;
        }
      } else if (node.type === 'variable_declarator' && node.firstNamedChild.type === 'identifier') {
        // For a variable declaration with a function expression (e.g., const myFunction = function() {...}),
        // find the identifier node that represents the variable name
        const identifierNode = node.firstNamedChild;
        return identifierNode.text;
      } else if (node.type === 'assignment_expression' && node.firstChild.type === 'member_expression') {
        // For an assignment expression with a member expression (e.g., STUI.updateContextLineCounts = function() {...}),
        // find the property identifier node that represents the function name
        const memberExpressionNode = node.firstChild;
        const propertyNode = memberExpressionNode.lastNamedChild;
        if (propertyNode && propertyNode.type === 'property_identifier') {
          return propertyNode.text;
        }
      }else if (node.type === 'assignment_expression') {
        // For an assignment expression (e.g., myObject.myFunction = function() {...}),
        // find the property node that represents the function name
        const leftNode = node.firstChild;
        if (leftNode && leftNode.type === 'member_expression') {
          const propertyNode = leftNode.lastNamedChild;
          if (propertyNode && propertyNode.type === 'property_identifier') {
            return `${leftNode.firstChild.text}.${propertyNode.text}`;
          }
        }
      }
      // For other node types, return the default name (node.type)
      return node.type;
  },     
   */
  traverseTree: function (node, excludeTop, excludeBottom) {
    //console.log("node data");
    //console.log(node);
    let me = this;
    let theIndex = parseInt(node.startPosition.row);
    let prevEndIndex = parseInt(node.endPosition.row) - 1;
    if(prevEndIndex < 0){
        prevEndIndex = 0;
    }
    let endIndex = parseInt(node.endPosition.row);
    const result = {
      startLine: parseInt(node.startPosition.row),
      endLine: parseInt(node.endPosition.row),
      type: this.getNodeType(node),
      lineText: this.fileLines[theIndex],
      linePrevEnd: this.fileLines[endIndex],
      lineEnd: this.fileLines[endIndex],
      children: []
    };
    let addNamedChildren = function(theNode){
        for (const child of theNode.namedChildren) {
            
            if (theNode.type === 'program') {
                
                result.children.push(TREESIT.traverseTree(child));
                continue;
            }         
            
            let parentDiff = node.endPosition.row - node.startPosition.row;

            
            let rowDiff = child.endPosition.row - child.startPosition.row;
            if(parentDiff > 100){
                result.children.push(TREESIT.traverseTree(child));
                continue;                   
            }            
            else if(rowDiff <= 2){
                //went deep enough                
                addNamedChildren(child);
            }
            else if(child.startPosition.row == node.startPosition.row && 
                    child.endPosition.row == node.endPosition.row && 
                        node.startPosition.row == node.endPosition.row){
                //it's one line, and parent is one line
                continue;
            }else if(child.startPosition.row == node.startPosition.row && 
                    child.endPosition.row == node.endPosition.row){
                //the child has same lines as parent, let's go down tree until child has different lines
                addNamedChildren(child);
            }else if(child.startPosition.row == node.startPosition.row){
                //the child has same start line as parent, let's go down tree until child has different start
                addNamedChildren(child);
            }
            else{
                result.children.push(TREESIT.traverseTree(child, result.startLine, result.endLine));
            }
        }
        
    };
    addNamedChildren(node);
    
    return result;
  },
  syntaxCheck: function(code, filename) {
    let ext = path2.extname(filename).slice(1);      
    let languageName = TREESIT.getLanguageByExt(ext);
    return new Promise((resolve, reject) => {
      this.initializeParser(languageName, () => {
          
        let ext = path2.extname(filename).slice(1);
        let result = this.parseAnyLanguage(code, ext, true);
        result['filename'] = filename;
        resolve(result);
      });
    });
  },
  findFirstErrorNode: function(node) {
      if (node.type === 'ERROR') {
        return node;
      }
      for (let child of node.children) {
        const errorNode = this.findFirstErrorNode(child);
        if (errorNode) {
          return errorNode;
        }
      }
      return null;
  },  
  getNodeType: function (node) {
    switch (node.type) {
      case 'function_declaration':
      case 'function':
      case 'arrow_function':
        return 'function';
      case 'class_declaration':
        return 'class';
      case 'variable_declaration':
        return 'variable';
      case 'pair':
        return 'function';
      case 'lexical_declaration':
        // Check if the value is a function or arrow function
        for (const child of node.namedChildren) {
          if (child.type === 'arrow_function' || child.type === 'function') {
            return 'function';
          }
        }
        return node.type;
      case 'expression_statement':
          return 'function';
      case 'object':
          return 'function';
        //for (const child of node.namedChildren) {
        //  if (child.type === 'arrow_function' || child.type === 'function') {
        //    return 'function';
        //  }
        //}     
      default:
        return node.type;
    }
  },
  getDetailNodeType: function (node) {
  switch (node.type) {
    case 'function_declaration':
    case 'arrow_function':
      return 'function';
    case 'class_declaration':
      return 'class';
    case 'lexical_declaration':
    case 'variable_declaration':
      // Check if the value is a function or arrow function
      if (node.namedChildren && node.namedChildren.length) {
        for (const child of node.namedChildren) {
          if (child.type === 'arrow_function' || child.type === 'function') {
            return 'function';
          }
        }
      }
      return 'variable';
    case 'pair':
      if (node.lastNamedChild && (node.lastNamedChild.type === 'function' || node.lastNamedChild.type === 'arrow_function')) {
        return 'function';
      }
      return node.type;
    case 'expression_statement':
      if (node.firstNamedChild && node.firstNamedChild.type === 'call_expression') {
        const firstChild = node.firstNamedChild.firstNamedChild;
        if (firstChild && firstChild.type === 'member_expression') {
          const lastChild = firstChild.lastNamedChild;
          if (lastChild && lastChild.type === 'property_identifier' && lastChild.text === 'on') {
            return 'event_handler';
          }
        }
      }
      return node.type;
    default:
      return node.type;
  }
},
getHtmlElementScopeForLine: async function(fileContent, lineIndex, ext = 'html') {
  return new Promise((resolve, reject) => {
    let isResolved = false;
    
    // Set a 2-second timeout
    const timeoutId = setTimeout(() => {
      if (!isResolved) {
        isResolved = true;
        console.warn("HTML parsing timed out after 2 seconds. Falling back.");
        resolve(null); // Resolve with null to indicate a timeout
      }
    }, 2000);
    let languageName = TREESIT.getLanguageByExt(ext);
    this.initializeParser(languageName, () => {
                //console.log("ext is: " + ext);
      this.parseAnyLanguage(fileContent, ext, false, (parsedTree) => {
        if (isResolved) return; // If already resolved due to timeout, don't proceed
        
        clearTimeout(timeoutId); // Clear the timeout as we've got a result
        
        const lines = fileContent.split('\n');
        const elementScope = this.findElementScope(parsedTree, lineIndex);
        if (elementScope) {
          isResolved = true;
          resolve({
            startLine: elementScope.startLine + 1, // Adjust for 1-based line numbers
            endLine: elementScope.endLine + 1,
            element: 'element',
            content: lines.slice(elementScope.startLine, elementScope.endLine + 1).join('\n')
          });
        } else {
          isResolved = true;
          console.log("Could not find HTML scope with Treesitter");
          resolve(null); // Resolve with null to indicate a timeout
        }
      });
    });
  });
},

findElementScope: function(node, targetLineIndex) {
  const targetElements = this.findTargetElements(node, targetLineIndex);
  //console.log("Target elements:", targetElements);

  if (targetElements.length === 0) {
    return null;
  }

  let maxEndLine = -1;
  targetElements.forEach(element => {
    const elementMaxEnd = this.findMaxEndLine(element);
    //console.log(`Max end line for element starting at line ${element.startLine + 1}: ${elementMaxEnd + 1}`);
    if (elementMaxEnd > maxEndLine) {
      maxEndLine = elementMaxEnd;
    }
  });

  //console.log(`Overall max end line: ${maxEndLine + 1}`);

  return {
    startLine: targetElements[0].startLine,
    endLine: maxEndLine
  };
},

findTargetElements: function(node, targetLineIndex) {
  let targetElements = [];
  if (node.startLine === targetLineIndex) {
    targetElements.push(node);
  }
  for (let child of node.children) {
    targetElements = targetElements.concat(this.findTargetElements(child, targetLineIndex));
  }
  return targetElements;
},

findMaxEndLine: function(element) {
  let maxEnd = element.endLine;
  for (let child of element.children) {
    const childMaxEnd = this.findMaxEndLine(child);
    if (childMaxEnd > maxEnd) {
      maxEnd = childMaxEnd;
    }
  }
  return maxEnd;
},
  getFileStub: function (filePath, existingMd5, foundIndex, callback) {
            let me = this;
            console.log("getting filestub: " + filePath);
            if (!fs2.existsSync(filePath)) {
              console.log("FILE DATA NOT FOUND: " + filePath);
              callback(null, null, -1);
              return;
            }
            let ext = path2.extname(filePath).slice(1);
            let languageName = this.getLanguageByExt(ext);
            if (!languageName) {
              console.log("Unknown language extension: " + ext);
              callback(null, null, -1);
              return;
            }
            let fileData;
            if (typeof readFileWithCache === 'function') {
              fileData = readFileWithCache(filePath);
            } else {
              console.log("Reading file without cache");
              fileData = fs2.readFileSync(filePath, 'utf-8');
            }
            this.parseAnyLanguage(fileData, ext, false, function(retNode) {
              if (!retNode) {
                console.log("Parsing failed for file: " + filePath);
                callback(null, existingMd5, foundIndex);
                return;
              }
                if(me.conDebug){                
                    //console.log("Got back nodes");
                    console.log(retNode);
                }
                let deleteSections = new Array();

                var processDeleteSections = function (node, theLevel) {
                    //console.log("testing delete for node:");
                    //console.log(node);
                    let deleteCount = deleteSections.length;
                    
                    // Check if the node has no children and spans more than 3 lines
                    let sectionLineCount = node.endLine - node.startLine;
                    if (node.children.length === 0 && (node.endLine - node.startLine) > 3) {      
                        //console.log("delete case 1");
                        deleteSections.push({
                            "start": node.startLine,
                            "end": node.endLine,
                            "node_type": node.type
                        });
                    }                    
                    else if(node.type == "function" && sectionLineCount < 100){      
                        //console.log("delete case 2");
                        deleteSections.push({
                            "start": node.startLine,
                            "end": node.endLine,
                            "node_type": node.type
                        });                        
                    }
                    else if(node.type == "comment"){
                        //console.log("delete case 3");                        
                        deleteSections.push({
                            "start": node.startLine,
                            "end": node.endLine,
                            "node_type": node.type
                        });                        
                    } 
                    else if(node.type == "variable" && sectionLineCount < 50){
                        //console.log("delete case 4");
                        deleteSections.push({
                            "start": node.startLine,
                            "end": node.endLine,
                            "node_type": node.type
                        });                        
                    }else if(node.type == "expression_statement" || node.type == "if_statement" || node.type == "else_clause" || 
                            node.type == "for_statement" || node.type == "try_statement"){
                        //console.log("delete case 5");                        
                        deleteSections.push({
                            "start": node.startLine,
                            "end": node.endLine,
                            "node_type": node.type
                        });                           
                    }else if(theLevel > 6){
                        //console.log("delete case 6");                                                
                        deleteSections.push({
                            "start": node.startLine,
                            "end": node.endLine,
                            "node_type": node.type
                        });                        
                    }
                    
                    if(deleteCount != deleteSections.length){
                        //console.log("ADDED DELETE ");
                        //console.log(deleteSections[deleteSections.length - 1]);
                        //console.log(node);
                    }
                        
                    let newLevel = theLevel + 1;
                    // Recursively process children nodes
                    if(node.type == 'formal_expression'){
                        //reset level
                        newLevel = theLevel - 1;
                    }
                    for (let child of node.children) {
                        processDeleteSections(child, newLevel);
                    }
                };

                processDeleteSections(retNode, 1);
                if(me.conDebug){   
                    //console.log("delete sections");
                    //console.log(deleteSections);
                }
                let testLines = fileData.split(/\r?\n/);
                let lastLineDeleted = false;
                let isLastLine = false;
                let finalLines = new Array();

                for (let m = 0; m < testLines.length; m++) {
                    let deleteIt = false;
                    let theIndex = m;
                    let biggestSectionAmount = -1;
                    let deleteSection = null;
                    for (let d = 0; d < deleteSections.length; d++) {
                        let sectionAmount = deleteSections[d].end - deleteSections[d].start;
                        if (theIndex > deleteSections[d].start && theIndex < deleteSections[d].end) {
                            if(this.conDebug){                               
                                console.log("deleting " + testLines[m] + "  ----------- because of: ");
                                console.log(deleteSections[d]);
                            }
                            deleteIt = true;
                            if(theIndex == deleteSections[d].end && !deleteSections[d].is_commment){
                                isLastLine = true;
                            }           
                            if(sectionAmount > biggestSectionAmount){
                                deleteSection = deleteSections[d];
                            }
                        }else if((deleteSections[d].node_type == 'comment' || deleteSections[d].node_type == 'variable' || deleteSections[d].node_type == 'expression_statement')                                 
                                && theIndex >= deleteSections[d].start && theIndex <= deleteSections[d].end) {
                            if(this.conDebug){   
                                console.log("deleting " + testLines[m] + "  ----------- because of: ");
                                console.log(deleteSections[d]);
                            }
                            deleteIt = true;
                            if(sectionAmount > biggestSectionAmount){
                                deleteSection = deleteSections[d];
                            }
                        }

                    }
                    if (testLines[m].trim() == "") {
                        deleteIt = true;
                    }
                    else if (testLines[m].trim() == "}") {
                        deleteIt = true;
                    }
                    if (isLastLine && deleteSection.node_type == 'function') {
                        isLastLine = false;
                        const matchText = testLines[m].match(/^(\s*)/);
                        let extraSpace = "";
                        if(matchText){
                            extraSpace = matchText[1];  
                        }
                        finalLines.push(extraSpace + "    /" + "/" + "omitted ");
                    }                          
                    if (!deleteIt) {
                        //maximum length of stub file line 500
                        if(testLines[m].length > 500){
                            finalLines.push(testLines[m].substring(0, 500));
                        }else{
                            finalLines.push(testLines[m]);
                        }
                        
                    }
                }

                let finalText = finalLines.join('\n');
                if(me.conDebug){   
                    console.log("finalLines");
                    console.log(finalLines);
                }
                //console.log("text");
                //console.log(finalText);
                callback(finalText, existingMd5, foundIndex);
            });
  },
  getLanguageByExt(theExt){
      let languageName = 'javascript';
    switch (theExt) {
      case 'js': languageName = 'javascript'; break;
      case 'php': languageName = 'php'; break;
      case 'sh': languageName = 'bash'; break;
      case 'c': languageName = 'c'; break;
      case 'cs': languageName = 'c_sharp'; break;
      case 'cpp':
      case 'cc':
      case 'cxx':
      case 'hpp':
      case 'hxx': languageName = 'cpp'; break;
      case 'css': languageName = 'css'; break;
      case 'elm': languageName = 'elm'; break;
      case 'html':
      case 'htm': languageName = 'html'; break;
      case 'java': languageName = 'java'; break;
      case 'lua': languageName = 'lua'; break;
      case 'md':
      case 'markdown': languageName = 'markdown'; break;
      case 'py': languageName = 'python'; break;
      case 'rb': languageName = 'ruby'; break;
      case 'rs': languageName = 'rust'; break;
      case 'ts': languageName = 'typescript'; break;
      case 'tsx': languageName = 'tsx'; break;
      case 'kt': languageName = 'kotlin'; break;
      case 'swift': languageName = 'swift'; break;      
      case 'json': languageName = 'json'; break;
      default:
        console.log("Unknown language extension: " + theExt);
        return languageName;
    }      
    return languageName;
  }  
};

if (!process.type) {
    module.exports = TREESIT;
}